@@ -1,16 +1,18 @@
-package HTML::Chunks;
+# $Id: Chunks.pm,v 1.51 2003/06/28 00:18:31 dbalmer Exp $
 
+package HTML::Chunks;
 use strict;
 
-our $VERSION = '1.55';
+use vars qw($VERSION);
+$VERSION = "1.51";
 
-use constant DATA_REGEX => qr/##[\w\.]+##/;
 
 sub new
 {
 	my $self = bless {}, shift;
 
-	$self->init(@_);
+	$self->init(@_) if @_;
+
 	return $self;
 }
 
@@ -22,7 +24,7 @@ sub init
 	$self->{cascade}   = 1;
 	$self->{dataStack} = [];
 	$self->{chunk}     = {};
-	$self->{default}   = undef;
+	$self->{default}   = '';
 	
 	$self->read(@_) if @_;
 }
@@ -132,7 +134,7 @@ sub output
 {
 	my $self = shift;
 	my $name = shift;
-
+	
 	$self->outputAsChunk(\$self->{chunk}{$name}, @_);
 }
 
@@ -147,34 +149,25 @@ sub outputAsChunk
 		$data ||= {};
 		
 		push @{$self->{dataStack}}, $data;
-		$self->outputBasicChunk($chunkRef, @_);
+		
+		foreach my $piece (split(/(?:<!--\s+)?(##[\w\.]+##)(?:\s+-->)?/, $$chunkRef)) {
+			if ($piece =~ /##([\w\.]+)##/) {
+				$self->outputData($1, @_);
+			}
+			else {
+				print $piece;
+			}
+		}
+		
 		pop @{$self->{dataStack}};
 	}
 }
 
-# basic chunk output including data substitution, using data already
-# on the data stack.
-sub outputBasicChunk
-{
-	my $self = shift;
-	my $chunk = shift; 
-	my $chunkRef = ref $chunk ? $chunk : \$chunk;
-	my $data_regex = $self->DATA_REGEX;
-
-	foreach my $piece (split(/(<!--\s*$data_regex\s*-->|$data_regex)/, $$chunkRef)) {
-		if ($piece =~ /($data_regex)/) {
-			$self->outputData(substr($1, 2, -2), @_);
-		}
-		else {
-			print $piece;
-		}
-	}
-}
-
 sub outputData
 {
 	my $self = shift;
 	my $name = shift;
+	
 	my $value = $self->getDataValue($name);
 	
 	if (ref $value eq 'CODE') {
@@ -270,11 +263,11 @@ __END__
 
 =head1 NAME
 
-HTML::Chunks - A simple nested template engine for HTML, XML and XHTML
+HTML::Chunks - A simple text-based template engine
 
 =head1 VERSION
 
-1.53
+$Revision: 1.5 $
 
 =head1 DESCRIPTION
 
@@ -286,9 +279,10 @@ generating email messages, XML data files, etc.
 
 =head1 SYNOPSIS
 
+ use HTML::Chunks;
+ 
  my $engine = new HTML::Chunks(@chunkFiles);
-
- $engine->readChunkFile('morechunks.html');
+ $engine->readChunkFile('morechunks.htm');
  $engine->addChunk($smallChunk, \$hugeChunk);
  $engine->addNamedChunk('myChunk', $chunk);
  
@@ -485,7 +479,7 @@ Consider the following chunk definition:
  </html>
  <!-- end MealPage -->
 
-Let's say this were in a file called I<meals.html>.  Because
+Let's say this were in a file called I<meals.htm>.  Because
 we embedded some chunk definitions within others, you could
 actually view it in a web browser and get a preview of things
 to come.  Again, embedding one definition within another means
@@ -500,7 +494,7 @@ it:
  
  # create a new engine and read our chunk definitions
  
- my $engine = new HTML::Chunks('meals.html');
+ my $engine = new HTML::Chunks('meals.htm');
  
  # output the main 'mealPage' chunk.  name information
  # is supplied with static text.  the 'meals' data element
@@ -539,20 +533,4 @@ it:
    }
  }
 
-=head1 SEE ALSO
-
-For the adventurous, there is L<HTML::Chunks::Super>, a subclass of
-HTML::Chunks with enhanced features.
-
-=head1 CREDITS
-
-Created, developed and maintained by Mark W Blythe and Dave Balmer, Jr.
-Contact dbalmer@cpan.org or mblythe@cpan.org for comments or questions.
-
-=head1 LICENSE
-
-(C)2001-2009 Mark W Blythe and Dave Balmer Jr, all rights reserved.
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
